@@ -1,4 +1,3 @@
-
 from ast import Str
 from tkinter.messagebox import NO
 from xmlrpc.client import TRANSPORT_ERROR
@@ -31,6 +30,8 @@ from pygame_widgets.dropdown import Dropdown
 start_time = 0
 anim_time = 1
 
+def passing():
+    pass
 
 pygame.init()
 
@@ -40,10 +41,79 @@ def Mod(num):
     if num < 0:num = -num
     return num
 def Get_GRPgraph_wersion():
-    print(colorama.Fore.BLUE+'GRPgraph version (16.8)'+colorama.Fore.RESET)
-def Get_fonts():
-    return pygame.font.get_fonts()
+    print(colorama.Fore.BLUE+'GRPgraph version (17.1)'+colorama.Fore.RESET)
+
+
+
+
+# Display
+Full = 'FULL'
+Resize = 'RESZ'
+Nones = 'NONE'
+
+#Colors
+c_RED = (255, 0, 0)
+c_GREEN = (0, 128, 0)
+c_BLUE = (0, 0, 255)
+c_YELLOW = (255, 255, 0)
+c_WHITE = (255, 255, 255)
+c_BLACK = (0, 0, 0)
+c_CYAN = (0, 255, 255)
+c_LIME = (0, 255, 0)
+c_DARK_GREEN = (0, 100, 0)
+c_CRIMSON = (220, 20, 60)
+c_PINK = (255, 192, 203)
+c_VIOLET = (238, 130, 238)
+c_PURPLE = (128, 0, 128)
+c_NAVY = (0, 0, 128)
+c_SKY_BLUE = (135, 206, 250)
+c_AQUA = (0, 255, 255)
+c_MAROON = (128, 0, 0)
+c_SILVER = (192, 192, 192)
+c_GRAY = (128, 128, 128)
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 # 1
+class Fonts(object):
+    def __init__(self):
+        pass
+
+    def Get_():
+        return pygame.font.get_fonts()
+
+    def Get_index(self,index):
+        return pygame.font.get_fonts()[index]
+
+    class Print_():
+        def __init__(self,Nums=False):
+            if Nums == False:
+                fonts = pygame.font.get_fonts()
+                for i in range(len(fonts)):
+                    print(colorama.Fore.GREEN + fonts[i] + colorama.Fore.RESET)
+
+            elif Nums == True:
+                fonts = pygame.font.get_fonts()
+                for i in range(len(fonts)):
+                    print(colorama.Fore.YELLOW +  '['+str(i)+'] - ' + colorama.Fore.RESET , end='') 
+                    print(colorama.Fore.GREEN + fonts[i] + colorama.Fore.RESET)      
+# 2
 class Vec2_:
         def __init__(self,vect2d_start=[-1],vect2d_end=[-1],pos=[0,0]): 
             if vect2d_start[0]!=-1 and vect2d_end[0]!=-1:
@@ -107,7 +177,7 @@ class Vec2_:
                     return True
             else:
                     return False     
-# 2
+# 3
 class Surfases_:
     def __init__(self,size=[],pos=[0,0],color=(200,200,200),alpha=0):
         self.screen = pygame.Surface((size[0],size[1]))
@@ -174,7 +244,7 @@ class Surfases_:
 
     def GET_DOWN(self):
         return [self.pos[0]+self.size[0]/2,self.pos[1]+self.size[1]]
-# 3        
+# 4       
 class Kamera_:
     def __init__(self,SIZE=[],zvet_prost='RGB',NUM=0):
         self.size = SIZE
@@ -205,7 +275,7 @@ class Kamera_:
     def GET_SETINGS(self):
         cont = self.cam.get_controls()
         return cont
-# 4
+# 5
 class Time_:
     def __init__(self):
         pass
@@ -219,7 +289,7 @@ class Time_:
             self.time = colc.get_time()
         def return_time(self):
             return self.time
-# 5 
+# 6 
 class Text_:
     def __init__(self,TEXT='',GLASS=False,COLOR=(),FONT='arial',SIZE=0,POSITION=[],BG_COLOR=None):  
         pygame.font.init()    
@@ -259,6 +329,8 @@ class Text_:
     def SET_FONT(self,FONT=None):
         self.font = FONT
         self.RENDER_TEXT = pygame.font.SysFont(self.font,self.pix)
+        RENDERING = self.RENDER_TEXT.render(self.text,self.glass,self.col,self.bg_color) 
+        self.RENDERING = RENDERING
 
     def GET_FONT(self):
         return self.font
@@ -287,7 +359,7 @@ class Text_:
     def SET_BG_COLOR(self,COLOR=None):
         self.bg_color = COLOR
         self.RENDERING = self.RENDER_TEXT.render(self.text,self.glass,self.col,self.bg_color)
-# 6 -- new !! do not work
+# 7 -- new !! do not work
 class Math_:
     def __init__(self):
         pass
@@ -332,7 +404,7 @@ class Math_:
                 self.num = random.random()
             def Get(self):
                 return self.num
-# 7 
+# 8 
 class Color_:
     def __init__(self,r,g,b,hsv=0):
         self.hsv = hsv
@@ -391,7 +463,7 @@ class Color_:
         hsv = 0
         col = Color_(gr,gr,gr,hsv)
         return col
-# 8 
+# 9 
 class Sub_events_:
     def __init__(self):
         pass
@@ -482,10 +554,11 @@ class Sub_events_:
                 print(colorama.Fore.YELLOW+'''flags : left , right'''+colorama.Fore.RESET)
                 sys.exit()
             mouse.double_click(BUTTON)
-# 9 
+# 10 
 class Display_init:
-    def __init__(self,size=[600,400],caption='Program',flags='NONE'):
-        global screen,clock
+    
+    def __init__(self,size=[600,400],caption='Program',flags=Nones,BG_COLOR='White'):
+        global screen,clock,bg_color
         self.caption = caption
 
         pygame.init()
@@ -514,6 +587,9 @@ class Display_init:
         self.height = screen.get_size()[1]
         self.win_size = screen.get_size()
         
+        self.col = BG_COLOR 
+        
+
         self.up = 0
         self.down = self.height
         self.left = 0
@@ -664,9 +740,8 @@ class Display_init:
         self.width = self.screen.get_width()
         self.height = self.screen.get_height()
 
-    class UPDATE():
-        def __init__(self):  
-            
+    class UPDATE(object):
+        def __init__(self):     
             pygame.display.flip()
 
         def GETTIME(self):
@@ -674,8 +749,10 @@ class Display_init:
             start_time+=1
             return start_time    
 
-        def SETBGCOLOR(self,col='white'):
-            screen.fill(col)
+        def SET_BG_COLOR(self,COLOR=None):
+            if COLOR is None:
+                COLOR = 'white'
+            screen.fill(COLOR)
 
     class GL:
                                             def __init__(self):
@@ -879,7 +956,7 @@ class Display_init:
                                                     else:self.surf = SURF
 
                                                     self.center = center
-                                                    self.pos = POSITION ; g_e_pos = self.pos
+                                                    self.pos = POSITION ; g_c_pos = self.pos
                                                     up_cic = [POSITION[0],POSITION[1]-self.rad] ; self.up = up_cic
                                                     down_cic = [POSITION[0],POSITION[1]+self.rad] ; self.down = down_cic
                                                     left_cic = [POSITION[0]-self.rad,POSITION[1]] ; self.left = left_cic
@@ -1005,13 +1082,13 @@ class Display_init:
                                                     el_right = [POSITION[0]+SIZE[0],POSITION[1]+SIZE[1]/2] ; self.right = el_right
                                                     
                                                     if FUNCTION=='D':    
-                                                        if g_pos!=None:self.pos = g_pos
+                                                        if g_e_pos!=None:self.pos = g_e_pos
                                                         rect = pygame.Rect(self.pos[0],self.pos[1],self.size[0],self.size[1])
                                                         pygame.draw.ellipse(self.surf,self.col,rect,self.sh)
                                                     elif FUNCTION[1]=='D':
                                                         COLOR = [int(FUNCTION[3:6]),int(FUNCTION[7:10]),int(FUNCTION[11:14])]
                                                         THICKNESS = int(FUNCTION[15:len(FUNCTION)])
-                                                        if g_pos!=None:self.pos = g_pos
+                                                        if g_e_pos!=None:self.pos = g_e_pos
 
                                                         rect = pygame.Rect(self.pos[0],self.pos[1],self.size[0],self.size[1])   
                                                         pygame.draw.ellipse(self.surf,self.col,rect,self.sh)
@@ -1026,7 +1103,7 @@ class Display_init:
                                                         THICKNESS = int(FUNCTION[14:len(FUNCTION)])
                                                         if COLOR!=None:self.obv_color = COLOR
                                                         if THICKNESS!=None:self.sh2 = THICKNESS
-                                                        if g_pos!=None:self.pos = g_pos
+                                                        if g_e_pos!=None:self.pos = g_e_pos
 
                                                         rect = pygame.Rect(self.pos[0],self.pos[1],self.size[0],self.size[1])
                                                         pygame.draw.ellipse(self.surf,self.obv_color,rect,self.sh2)
@@ -1399,7 +1476,7 @@ class Display_init:
                                                     self.sh = sh2
                                                 def Get_sh(self):
                                                     return self.sh
-# 10 
+# 11 
 class Sprites_(Surfases_):
     def __init__(self,file=''):
         img = pygame.image.load(file)
@@ -1444,7 +1521,7 @@ class Sprites_(Surfases_):
 
     def Get_pos(self):
         return self.pos
-# 11 -- new !! do not work
+# 12 -- new !! do not work
 class Sprites_Group_:
     def __init__(self,sprites=[]):
         self.sprites = sprites
@@ -1456,7 +1533,7 @@ class Sprites_Group_:
         self.rect = self.sprites_pack[sprite_index].get_rect(bottomright=(pos[0]+self.sprites_pack[sprite_index].get_width(),
                                                                           pos[1]+self.sprites_pack[sprite_index].get_height())) 
         screen.blit(self.sprites_pack[sprite_index],self.rect)
-# 12
+# 13
 class Graphick_:
     def __init__(self):
         pass
@@ -1483,10 +1560,28 @@ class Graphick_:
 
 
             g1 +=1
-# 13 -- new !!
+# 14 -- new !!
 class Widgets_:
     def __init__(self):
-        pass
+        self.widgets = [
+            'Slider',
+            'Button',
+            'Toggle',
+            'Textbox',
+            'Dropdown'
+        ]
+    def Get_Print_Widgets(self,index=None):
+        if index is None:
+            for i in range(len(self.widgets)):
+                print(colorama.Fore.RED + f'[ {i} ] - ' + colorama.Fore.RESET,end='')
+                print(colorama.Fore.YELLOW + self.widgets[i] + colorama.Fore.RESET)
+
+        elif index is not None:
+            print(self.widgets)
+
+    def Get_Widgets(self):
+        return self.widgets
+
     class Sliders:
         def __init__(self,plane,
                             pos=[],
@@ -2148,7 +2243,7 @@ class Widgets_:
 
         def Disable(self):
             self.dd.disable()
-# 14 -- new !!
+# 15 -- new !!
 class Objectes_:
     def __init__(self,name='obj'):
         self.name = name
@@ -2178,7 +2273,7 @@ class Objectes_:
 
     def Get_pack(self):
         return self.pack
-# 15 -- new !!
+# 16 -- new !!
 class Img_:
     def __init__(self,surface):
         self.surface = surface
